@@ -49,7 +49,9 @@ def get_by_id(category_id):
     return Category.get_by_id(category_id)
 
 
-def get_all_categories_ids_by_parent_slug_and_refinement_id(parent_slug, refinement_id):
+def get_all_categories_ids_by_parent_slug_and_refinement_id(
+    parent_slug, refinement_id
+):
     """Get a list of all category ids by parent_slug and refinement id.
 
     Args:
