@@ -3,18 +3,20 @@
 from django.urls import re_path
 from rest_framework.urlpatterns import format_suffix_patterns
 
-import core_main_app.rest.xsl_transformation.views as xslTransformationList_view
 from core_main_app.rest.data import views as data_views
 from core_main_app.rest.template import views as template_views
 from core_main_app.rest.template_version_manager import (
     views as template_version_manager_views,
 )
+import core_main_app.rest.xsl_transformation.views as xslTransformationList_view
 from core_main_app.rest.user import views as user_views
 from core_main_app.rest.workspace import views as workspace_views
+
 from core_main_registry_app.rest.data import views as registry_data_views
 from core_main_registry_app.rest.template_version_manager import (
     views as registry_template_version_manager_views,
 )
+from core_main_registry_app.settings import ENABLE_BLOB_ENDPOINTS
 
 urlpatterns = [
     re_path(
@@ -22,6 +24,11 @@ urlpatterns = [
         template_version_manager_views.GlobalTemplateVersionManagerList.as_view(),
         name="core_main_app_rest_template_version_manager_global_list",
     ),
+    re_path(
+        r"^template-version-manager/all/$",
+        template_version_manager_views.GlobalAndUserTemplateVersionManagerList.as_view(),
+        name="core_main_app_rest_all_template_version_manager_list",
+    ),
     re_path(
         r"^template-version-manager/(?P<pk>\w+)/$",
         template_version_manager_views.TemplateVersionManagerDetail.as_view(),
@@ -58,7 +65,9 @@ urlpatterns = [
         name="core_main_app_rest_template_detail",
     ),
     re_path(
-        r"^data/$", data_views.DataList.as_view(), name="core_main_app_rest_data_list"
+        r"^data/$",
+        data_views.DataList.as_view(),
+        name="core_main_app_rest_data_list",
     ),
     re_path(
         r"^data/permissions/$",
@@ -253,3 +262,46 @@ urlpatterns = [
 ]
 
 urlpatterns = format_suffix_patterns(urlpatterns)
+
+if ENABLE_BLOB_ENDPOINTS:
+    from core_main_app.rest.blob import views as blob_views
+
+    urlpatterns.extend(
+        [
+            re_path(
+                r"^admin/blob/$",
+                blob_views.BlobListAdmin.as_view(),
+                name="core_main_app_rest_blob_list_admin",
+            ),
+            re_path(
+                r"^blob/$",
+                blob_views.BlobList.as_view(),
+                name="core_main_app_rest_blob_list",
+            ),
+            re_path(
+                r"^blobs/delete/$",
+                blob_views.BlobDeleteList.as_view(),
+                name="core_main_app_rest_blob_delete_list",
+            ),
+            re_path(
+                r"^blob/(?P<pk>\w+)/$",
+                blob_views.BlobDetail.as_view(),
+                name="core_main_app_rest_blob_detail",
+            ),
+            re_path(
+                r"^blob/download/(?P<pk>\w+)/$",
+                blob_views.BlobDownload.as_view(),
+                name="core_main_app_rest_blob_download",
+            ),
+            re_path(
+                r"^blob/(?P<pk>\w+)/assign/(?P<workspace_id>\w+)$",
+                blob_views.BlobAssign.as_view(),
+                name="core_main_app_rest_blob_assign",
+            ),
+            re_path(
+                r"^blob/(?P<pk>\w+)/change-owner/(?P<user_id>\w+)$",
+                blob_views.BlobChangeOwner.as_view(),
+                name="core_main_app_rest_blob_change_owner",
+            ),
+        ]
+    )
