@@ -25,7 +25,11 @@ schema_view = get_schema_view(
 
 urlpatterns = [
     re_path(r"^$", user_views.homepage, name="core_main_app_homepage"),
-    re_path(r"^locked", common_views.defender_error_page, name="core_main_app_locked"),
+    re_path(
+        r"^locked",
+        common_views.defender_error_page,
+        name="core_main_app_locked",
+    ),
     re_path(r"^rest/", include("core_main_registry_app.rest.urls")),
     re_path(
         r"^data",
@@ -56,7 +60,9 @@ urlpatterns = [
     re_path(
         r"^change-workspace",
         login_required(
-            user_ajax.LoadFormChangeWorkspace.as_view(show_global_workspace=False)
+            user_ajax.LoadFormChangeWorkspace.as_view(
+                show_global_workspace=False
+            )
         ),
         name="core_main_change_workspace",
     ),
@@ -80,7 +86,9 @@ urlpatterns = [
         user_ajax.add_user_right_to_workspace,
         name="core_main_add_user_right_to_workspace",
     ),
-    re_path(r"^switch-right", user_ajax.switch_right, name="core_main_switch_right"),
+    re_path(
+        r"^switch-right", user_ajax.switch_right, name="core_main_switch_right"
+    ),
     re_path(
         r"^remove-rights",
         user_ajax.remove_user_or_group_rights,
@@ -103,7 +111,9 @@ urlpatterns = [
     ),
     re_path(r"^tz_detect/", include("tz_detect.urls")),
     re_path(
-        r"^password_reset/$", user_views.custom_reset_password, name="password_reset"
+        r"^password_reset/$",
+        user_views.custom_reset_password,
+        name="password_reset",
     ),
     re_path(
         r"^password_reset/done/$",
@@ -133,7 +143,9 @@ if settings.ENABLE_SAML2_SSO_AUTH:
     urlpatterns.append(re_path(r"saml2/", include("djangosaml2.urls")))
     urlpatterns.append(
         re_path(
-            r"^saml2/login", saml2_views.LoginView.as_view(), name="core_main_app_login"
+            r"^saml2/login",
+            saml2_views.LoginView.as_view(),
+            name="core_main_app_login",
         )
     )
     urlpatterns.append(
@@ -148,7 +160,9 @@ else:
         re_path(r"^login", user_views.custom_login, name="core_main_app_login")
     )
     urlpatterns.append(
-        re_path(r"^logout", user_views.custom_logout, name="core_main_app_logout")
+        re_path(
+            r"^logout", user_views.custom_logout, name="core_main_app_logout"
+        )
     )
 
 if ENABLE_BLOB_ENDPOINTS:
